@@ -2,7 +2,10 @@ import os
 import kaa
 import kaa.log
 import kaa.utils
-from kaa.command import Commands, commandid, is_enable, norec, norerun
+from kaa.command import Commands
+from kaa.command import commandid
+from kaa.command import norec
+from kaa.command import norerun
 
 
 class FileCommands(Commands):
@@ -70,6 +73,10 @@ class FileCommands(Commands):
             editor = kaa.app.show_doc(doc)
             self.restore_file_loc(editor)
 
+        if not filename:
+            if wnd and wnd.document.fileinfo:
+                filename = wnd.document.fileinfo.dirname
+
         from kaa.ui.selectfile import selectfile
         selectfile.show_fileopen(filename, cb)
 
@@ -86,7 +93,7 @@ class FileCommands(Commands):
     def file_viewdiff(self, wnd, callback=None):
         if wnd.document.fileinfo and wnd.document.fileinfo.fullpathname:
             from kaa.ui.viewdiff import viewdiffmode
-            viewdiffmode.view_diff(wnd.document, callback=None)
+            viewdiffmode.view_doc_diff(wnd.document, callback=None)
 
     @commandid('file.save')
     @norec
@@ -135,7 +142,6 @@ class FileCommands(Commands):
 
         from kaa.ui.selectfile import selectfile
 
-        filename = document.get_filename()
         if document.fileinfo:
             newline = document.fileinfo.newline
             encoding = document.fileinfo.encoding
@@ -158,7 +164,7 @@ class FileCommands(Commands):
 
                 if document.fileinfo and document.fileinfo.fullpathname:
                     from kaa.ui.viewdiff import viewdiffmode
-                    viewdiffmode.view_diff(document, callback=cb)
+                    viewdiffmode.view_doc_diff(document, callback=cb)
                 else:
                     cb()
 
@@ -381,7 +387,7 @@ class FileCommands(Commands):
 
                 if document.fileinfo and document.fileinfo.fullpathname:
                     from kaa.ui.viewdiff import viewdiffmode
-                    viewdiffmode.view_diff(
+                    viewdiffmode.view_doc_diff(
                         document, callback=cb)
                 else:
                     cb()
@@ -424,7 +430,6 @@ class FileCommands(Commands):
     @norerun
     def file_new_to(self, wnd):
         def openfile(cb):
-            from kaa import fileio
             doc = kaa.app.storage.newfile()
             wnd.show_doc(doc)
 
@@ -435,8 +440,12 @@ class FileCommands(Commands):
     @norerun
     def file_open_to(self, wnd):
         def openfile(cb):
+            if wnd.document.fileinfo:
+                filename = wnd.document.fileinfo.dirname
+            else:
+                filename = ''
             from kaa.ui.selectfile import selectfile
-            selectfile.show_fileopen('', cb)
+            selectfile.show_fileopen(filename, cb)
 
         self._open_file_to_wnd(wnd, openfile)
 
