@@ -1,12 +1,9 @@
-import itertools
-import re
 import functools
-import unicodedata
 import kaa
-from kaa.command import Commands, commandid, is_enable, norec, norerun
-from kaa import document
-from kaa.filetype.default import modebase
-from kaa import doc_re
+from kaa.command import Commands
+from kaa.command import commandid
+from kaa.command import norec
+from kaa.command import norerun
 
 
 class ViCommands(Commands):
