@@ -6,6 +6,7 @@ MENUS = {
      ['[&Code]', 'CODE', None],
      ['[&Macro]', 'MACRO', None],
      ['[&Tools]', 'TOOLS', None],
+     ['[&Git]', 'GIT', None],
      ['[&Window]', 'WINDOW', None]],
 
     'FILE':
@@ -59,6 +60,11 @@ MENUS = {
      ['Python debugger s&erver', None, 'python.debugger.server'],
      ],
 
+    'GIT':
+    [['&Status', None, 'git.status'],
+     ['&Log', None, 'git.log'],
+     ],
+
     'WINDOW':
     [['&Frame list', None, 'app.show-framelist'],
      ['Split &vert', None, 'editor.splitvert'],
