@@ -1,6 +1,6 @@
 from kaa.filetype.default import defaultmode
-from kaa.highlight import Tokenizer, Span
-from kaa.theme import Theme, Style
+from kaa.theme import Style
+from kaa.syntax_highlight import *
 
 DiffThemes = {
     'basic': [
@@ -15,23 +15,21 @@ DiffThemes = {
 }
 
 
-def build_tokenizer():
-    return Tokenizer([
-        Span('diff-fromfile', 'fromfile', r'^---', '$'),
-        Span('diff-tofile', 'tofile', r'^\+\+\+', '$'),
-        Span('diff-hunk', 'hunk', r'^@@', '@@'),
-        Span('diff-add', 'add', r'^\+', '$'),
-        Span('diff-remove', 'remove', r'^-', '$'),
-        Span('diff-header', 'header', r'^\S+', '$'),
+def make_tokenizer():
+    return Tokenizer(tokens=[
+        ('fromfile', Span('fromfile', r'^---', '$')),
+        ('tofile', Span('tofile', r'^\+\+\+', '$')),
+        ('hunk', Span('hunk', r'^@@', '@@')),
+        ('add', Span('add', r'^\+', '$')),
+        ('remove', Span('remove', r'^-', '$')),
+        ('header', Span('header', r'^\S+', '$')),
     ])
 
 
 class DiffMode(defaultmode.DefaultMode):
     MODENAME = 'Diff'
+    tokenizer = make_tokenizer()
 
     def init_themes(self):
         super().init_themes()
         self.themes.append(DiffThemes)
-
-    def init_tokenizers(self):
-        self.tokenizers = [build_tokenizer()]
