@@ -1,9 +1,9 @@
+import unicodedata
 import re
 import kaa
 from kaa import document
 from kaa.ui.dialog import dialogmode
-from kaa.theme import Theme, Style
-from kaa.ui.dialog import dialogmode
+from kaa.theme import Style
 
 MsgBoxThemes = {
     'basic': [
@@ -21,7 +21,7 @@ class MsgBoxMode(dialogmode.DialogMode):
     SEPARATOR = '/'
     USE_UNDO = False
     DELAY_STR = False
-    
+
     def init_themes(self):
         super().init_themes()
         self.themes.append(MsgBoxThemes)
@@ -34,15 +34,12 @@ class MsgBoxMode(dialogmode.DialogMode):
 
         wnd.CURSOR_TO_MIDDLE_ON_SCROLL = False
 
-    def on_str(self, wnd, s, overwrite=False):
-        pass
-
-    def on_start(self, wnd):
+    def on_dialog_start(self, wnd):
         wnd.cursor.setpos(self.document.endpos() - 1)
 
     def on_str(self, wnd, s, overwrite=False):
+        s = unicodedata.normalize('NFKC', s).lower()
         for c in s:
-            c = c.lower()
             if c in self.shortcuts:
                 self.on_shortcut(wnd, c)
                 return
@@ -97,8 +94,7 @@ class MsgBoxMode(dialogmode.DialogMode):
 
                 f.append_text('button',
                               option,
-                              on_shortcut=
-                              lambda wnd, key=shortcut: mode.on_shortcut(
+                              on_shortcut=lambda wnd, key=shortcut: mode.on_shortcut(
                                   wnd, key),
                               shortcut_style='button.shortcut')
 
