@@ -4,11 +4,9 @@ from kaa import document
 from kaa.ui.dialog import dialogmode
 from kaa.ui.selectlist import selectlist
 
-from kaa.theme import Theme, Style
 
 from kaa.command import commandid, norec, norerun
 from kaa.keyboard import *
-from kaa.commands import editorcommand
 import kaa.filetype.default.keybind
 
 
@@ -87,8 +85,10 @@ FilterListInputDlgThemes = {
 filterlistinputdlg_keys = {
     down: 'filterlistdlg.next',
     (ctrl, 'n'): 'filterlistdlg.next',
+    tab: 'filterlistdlg.next',
     up: 'filterlistdlg.prev',
     (ctrl, 'p'): 'filterlistdlg.prev',
+    (shift, tab): 'filterlistdlg.prev',
     '\r': 'filterlistdlg.select',
     '\n': 'filterlistdlg.select',
 }
