@@ -1,14 +1,11 @@
-import re
 import enchant
 import kaa
 from kaa import document
 from kaa.ui.dialog import dialogmode
 from kaa.ui.selectlist import filterlist
-from kaa.command import commandid, norec, norerun
 from kaa.keyboard import *
 from kaa import doc_re
 from kaa.ui.wordcomplete import wordcompletemode
-from kaa.ui.selectlist import filterlist
 
 
 class SpellCheckerWordInputMode(wordcompletemode.WordCompleteInputMode):
